package com.gxlu.ps.netcruise.md.nmsctrl;

import com.gxlu.ps.netcruise.md.GlobalInstance;
import com.gxlu.ps.netcruise.md.util.Alarm;
import com.gxlu.ps.netcruise.md.util.Command;
import com.gxlu.ps.netcruise.md.util.DateTool;
import com.gxlu.ps.netcruise.md.util.WinStyleLineReader;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.net.InetSocketAddress;
import java.net.Socket;
import java.net.SocketTimeoutException;
import java.net.UnknownHostException;

/* loaded from: com_gxlu_ps_netcruise_md_nmsctrl.jar:com/gxlu/ps/netcruise/md/nmsctrl/CommandSocket.class */
public class CommandSocket {
    private Socket clientSock;
    private WinStyleLineReader commandReceiver;
    private PrintWriter commandSender;
    private String NMSIP;
    private int NMSRemotePort;
    private int NMSLocalPort;
    private NMSCommunicator parent;
    private int commandChannelStatus = 1;
    private long maxRetryInterval = (GlobalInstance.getInstance().getConfiger().getMaxRetryInterval() * 60) * 1000;
    private boolean isShutdown = false;

    public CommandSocket() {
    }

    public CommandSocket(String IP, int remotePort, int localPort, NMSCommunicator communicator) {
        this.NMSIP = IP;
        this.NMSRemotePort = remotePort;
        this.NMSLocalPort = localPort;
        this.parent = communicator;
    }

    public void setupCommandChannel() {
        int index = 0;
        while (true) {
            if ((this.clientSock != null && this.commandChannelStatus == 2) || this.isShutdown) {
                return;
            }
            if (index > 0) {
                try {
                    long sleepTime = ((long) Math.pow(2.0d, index)) * 1000;
                    if (sleepTime >= this.maxRetryInterval || sleepTime < 0) {
                        Thread.sleep(this.maxRetryInterval);
                    } else {
                        Thread.sleep(sleepTime);
                    }
                } catch (UnknownHostException var6) {
                    GlobalInstance.getInstance().getLogger().error("Command channel failed ".concat(String.valueOf(String.valueOf(var6.getMessage()))));
                } catch (IOException var8) {
                    GlobalInstance.getInstance().getLogger().error("Command channel failed ".concat(String.valueOf(String.valueOf(var8.getMessage()))));
                    if (index < this.maxRetryInterval) {
                        index++;
                    }
                } catch (InterruptedException var7) {
                    GlobalInstance.getInstance().getLogger().error("Thread interrupted ".concat(String.valueOf(String.valueOf(var7.getMessage()))));
                }
            }
            if (this.clientSock != null) {
                if (!this.clientSock.isClosed()) {
                    this.clientSock.close();
                }
                this.clientSock = null;
            }
            this.clientSock = new Socket();
            this.clientSock.setReuseAddress(true);
            this.clientSock.connect(new InetSocketAddress(this.NMSIP, this.NMSRemotePort));
            this.clientSock.setSoTimeout(GlobalInstance.getInstance().getConfiger().getTimeOut() * 1000);
            this.commandReceiver = new WinStyleLineReader(new BufferedReader(new InputStreamReader(this.clientSock.getInputStream())));
            this.commandSender = new PrintWriter(this.clientSock.getOutputStream());
            this.commandChannelStatus = 2;
            String now = DateTool.getNow();
            Alarm aItem = new Alarm();
            aItem.setContent(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(GlobalInstance.getInstance().getErrParser().getErrDescription(803)))).append("|").append(now).append("\r\n"))));
            GlobalInstance.getInstance().getAlarmPool().saveAlarm(aItem, 1);
            GlobalInstance.getInstance().getLogger().debug(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat(":Command channel created "));
        }
    }

    public int syncAlarm() {
        Object var1 = this.parent.receiveStatusLock;
        synchronized (var1) {
            while (this.parent.getAlarmChannelStatus() == 1 && !this.isShutdown) {
                try {
                    GlobalInstance.getInstance().getLogger().debug(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat(":Wait alarm channel to created "));
                    this.parent.receiveStatusLock.wait(2000L);
                } catch (InterruptedException var12) {
                    GlobalInstance.getInstance().getLogger().error("Command thread interrupted ".concat(String.valueOf(String.valueOf(var12.getMessage()))));
                }
            }
        }
        while (!this.isShutdown) {
            this.commandChannelStatus = 3;
            try {
                if (this.parent.getNMSSyncTime() != null) {
                    this.commandSender.print(String.valueOf(String.valueOf(new StringBuffer("Sync ").append(this.parent.getNMSSyncTime()).append("\r").append("\n"))));
                    GlobalInstance.getInstance().getLogger().debug(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Start to sync alarm ").append(this.parent.getNMSSyncTime()))));
                } else {
                    this.commandSender.print("Sync \r\n");
                    GlobalInstance.getInstance().getLogger().debug(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat(":Start to sync alarm all"));
                }
                this.commandSender.flush();
                this.clientSock.setSoTimeout(0);
                String line = this.commandReceiver.readLine();
                if (line == null) {
                    GlobalInstance.getInstance().getLogger().error(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat(":Sync alarm get return code failed"));
                    String alarmContent = DateTool.getNow();
                    Alarm aItem = new Alarm();
                    aItem.setContent(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(GlobalInstance.getInstance().getErrParser().getErrDescription(802)))).append("|").append(alarmContent).append("\r\n"))));
                    GlobalInstance.getInstance().getAlarmPool().saveAlarm(aItem, 1);
                    this.commandChannelStatus = 1;
                    setupCommandChannel();
                } else {
                    int retCode = parseCode(line);
                    GlobalInstance.getInstance().getLogger().debug(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Get sync return=").append(retCode))));
                    if (retCode != -1 && retCode != 501) {
                        this.commandChannelStatus = 4;
                        return retCode;
                    }
                    if (retCode != -1) {
                        String alarmContent2 = this.commandReceiver.readLine();
                        while (alarmContent2 != null && alarmContent2.length() != 2) {
                            GlobalInstance.getInstance().getLogger().debug(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Receive sync alarm").append(alarmContent2))));
                            String alarmContent3 = alarmContent2.substring(0, alarmContent2.length() - 2);
                            String now = DateTool.getNow();
                            Alarm aItem2 = new Alarm();
                            aItem2.setContent(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append("|").append(alarmContent3).append("|").append(now).append("\r\n"))));
                            GlobalInstance.getInstance().getAlarmPool().saveAlarm(aItem2, 2);
                            alarmContent2 = this.commandReceiver.readLine();
                        }
                        this.commandChannelStatus = 4;
                        GlobalInstance.getInstance().getLogger().debug(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat(":Sync alarm finished"));
                        this.clientSock.setSoTimeout(GlobalInstance.getInstance().getConfiger().getTimeOut() * 1000);
                        return retCode;
                    }
                    GlobalInstance.getInstance().getLogger().error(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat(":Sync alarm get return code failed"));
                    String alarmContent4 = DateTool.getNow();
                    Alarm aItem3 = new Alarm();
                    aItem3.setContent(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(GlobalInstance.getInstance().getErrParser().getErrDescription(802)))).append("|").append(alarmContent4).append("\r\n"))));
                    GlobalInstance.getInstance().getAlarmPool().saveAlarm(aItem3, 1);
                    this.commandChannelStatus = 1;
                    setupCommandChannel();
                }
            } catch (SocketTimeoutException var13) {
                GlobalInstance.getInstance().getLogger().error(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Sync alarm failed").append(var13.getMessage()))));
                String now2 = DateTool.getNow();
                Alarm aItem4 = new Alarm();
                aItem4.setContent(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(GlobalInstance.getInstance().getErrParser().getErrDescription(802)))).append("|").append(now2).append("\r\n"))));
                GlobalInstance.getInstance().getAlarmPool().saveAlarm(aItem4, 1);
                this.commandChannelStatus = 1;
                setupCommandChannel();
            } catch (IOException var14) {
                GlobalInstance.getInstance().getLogger().error(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Sync alarm failed").append(var14.getMessage()))));
                String now3 = DateTool.getNow();
                Alarm aItem5 = new Alarm();
                aItem5.setContent(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(GlobalInstance.getInstance().getErrParser().getErrDescription(802)))).append("|").append(now3).append("\r\n"))));
                GlobalInstance.getInstance().getAlarmPool().saveAlarm(aItem5, 1);
                this.commandChannelStatus = 1;
                setupCommandChannel();
            }
        }
        return -1;
    }

    public int sendCommand(String commandName, String parms) {
        while (!this.isShutdown) {
            try {
                this.commandSender.print(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(commandName))).append(" ").append(parms).append("\r").append("\n"))));
                GlobalInstance.getInstance().getLogger().debug(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Send command =").append(commandName).append(" ").append(parms))));
                this.commandSender.flush();
                String line = this.commandReceiver.readLine();
                if (line == null) {
                    GlobalInstance.getInstance().getCmdPool().pushbackCmd(new Command(commandName, parms));
                    GlobalInstance.getInstance().getLogger().error(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat(":Command send failed,command return code is wrong"));
                    this.commandChannelStatus = 1;
                    setupCommandChannel();
                    syncAlarm();
                } else {
                    GlobalInstance.getInstance().getLogger().trace(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Receive command return line=").append(line))));
                    int retCode = parseCode(line);
                    GlobalInstance.getInstance().getLogger().debug(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Receive command return code=").append(retCode))));
                    if (retCode == -1) {
                        GlobalInstance.getInstance().getCmdPool().pushbackCmd(new Command(commandName, parms));
                        GlobalInstance.getInstance().getLogger().error(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat(":Command send failed,command return code is wrong"));
                        this.commandChannelStatus = 1;
                        setupCommandChannel();
                        syncAlarm();
                    } else {
                        if (retCode != 501) {
                            this.commandChannelStatus = 5;
                            return retCode;
                        }
                        if (commandName.equals("Time")) {
                            String alarmContent = this.commandReceiver.readLine();
                            GlobalInstance.getInstance().getLogger().debug(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Receive command return message=").append(alarmContent))));
                            if (alarmContent != null && alarmContent.length() != 2) {
                                this.parent.setTimeBetween(DateTool.getTimeDiffer(alarmContent));
                                return retCode;
                            }
                            GlobalInstance.getInstance().getLogger().error(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat(":Command send failed,return code is wrong"));
                            this.commandChannelStatus = 1;
                            setupCommandChannel();
                            syncAlarm();
                        } else if (commandName.equals("Sync")) {
                            String alarmContent2 = this.commandReceiver.readLine();
                            while (alarmContent2 != null && alarmContent2.length() != 2) {
                                GlobalInstance.getInstance().getLogger().info(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Receive sync alarm").append(alarmContent2))));
                                String now = DateTool.getNow();
                                String alarmContent3 = alarmContent2.substring(0, alarmContent2.length() - 2);
                                Alarm aItem = new Alarm();
                                aItem.setContent(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append("|").append(alarmContent3).append("|").append(now).append("\r\n"))));
                                GlobalInstance.getInstance().getAlarmPool().saveAlarm(aItem, 2);
                                alarmContent2 = this.commandReceiver.readLine();
                            }
                            GlobalInstance.getInstance().getLogger().debug(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat(":Sync alarm finished"));
                            return retCode;
                        }
                    }
                }
            } catch (SocketTimeoutException var8) {
                GlobalInstance.getInstance().getLogger().error(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Command send failed").append(var8.getMessage()))));
                String alarmContent4 = DateTool.getNow();
                Alarm aItem2 = new Alarm();
                aItem2.setContent(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(GlobalInstance.getInstance().getErrParser().getErrDescription(802)))).append("|").append(alarmContent4).append("\r\n"))));
                GlobalInstance.getInstance().getAlarmPool().saveAlarm(aItem2, 1);
                this.commandChannelStatus = 1;
                setupCommandChannel();
                syncAlarm();
            } catch (IOException var9) {
                GlobalInstance.getInstance().getLogger().error(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Command send failed").append(var9.getMessage()))));
                this.commandChannelStatus = 1;
                setupCommandChannel();
                syncAlarm();
            }
        }
        if (this.commandChannelStatus == 1) {
            GlobalInstance.getInstance().getCmdPool().pushbackCmd(new Command(commandName, parms));
            return -1;
        }
        return -1;
    }

    public int getCommandChannelStatus() {
        return this.commandChannelStatus;
    }

    public void setShutdown(boolean shutdown) {
        this.isShutdown = shutdown;
    }

    public void shutdownCommandChannel() {
        try {
            if (this.commandReceiver != null) {
                this.commandReceiver.close();
            }
            if (this.commandSender != null) {
                this.commandSender.close();
            }
            if (this.clientSock != null) {
                this.clientSock.close();
            }
            GlobalInstance.getInstance().getLogger().info(String.valueOf(String.valueOf(this.parent.getSpecailty())).concat(":Command channel shutdown"));
        } catch (IOException var2) {
            GlobalInstance.getInstance().getLogger().error(String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(this.parent.getSpecailty()))).append(":Command channel shutdown failed").append(var2.getMessage()))));
            this.commandChannelStatus = 1;
        }
    }

    private int parseCode(String code) {
        if (code.length() >= 3) {
            try {
                int retCode = Integer.parseInt(code.substring(0, 3));
                if (retCode != 100 && retCode != 200 && retCode != 300 && retCode != 400 && retCode != 500 && retCode != 501) {
                    return -1;
                }
                return retCode;
            } catch (NumberFormatException e) {
                return -1;
            }
        }
        return -1;
    }
}
